@@ -6,7 +6,8 @@
 import unittest
 
 from click.testing import CliRunner
-from deftlariat.entrypoints import cli
+from deftlariat.scripts import cli
+from hamcrest import *
 
 
 class TestSrc(unittest.TestCase):
@@ -24,10 +25,11 @@ class TestSrc(unittest.TestCase):
     def test_command_line_interface(self):
         """Test the CLI."""
         runner = CliRunner()
-        result = runner.invoke(cli.main)
+        result = runner.invoke(cli.deft_cli)
         print(result.output)
         assert result.exit_code == 0
         assert 'deft lariats' in result.output
-        help_result = runner.invoke(cli.main, ['--help'])
+        help_result = runner.invoke(cli.deft_cli, ['--help'])
         assert help_result.exit_code == 0
-        assert '--help  Show this message and exit.' in help_result.output
+        assert_that(help_result.output, string_contains_in_order('--version', '--help'))
+
